@@ -4,7 +4,7 @@
 		     http://wolfpack.twu.net/libjsw
 
 
-	Copyright (C) 1997-2005 WolfPack Entertainment.
+	Copyright (C) 1997-2006 WolfPack Entertainment.
 
 	For documentation and examples, see:
 	http://wolfpack.twu.net/libjsw
@@ -25,10 +25,10 @@ extern "C" {
 /*
  *	Version:
  */
-#define JSWVersion		"1.5.5"
-#define JSWVersionMajor		1
-#define JSWVersionMinor		5
-#define JSWVersionRelease	5
+#define JSWVersion			"1.5.6"
+#define JSWVersionMajor			1
+#define JSWVersionMinor			5
+#define JSWVersionRelease		6
 
 
 /*
@@ -54,49 +54,49 @@ extern "C" {
  *	never be used as a substitute for calibrated values. Always
  *	use calibrated values when possible.
  */
-#define JSDefaultMin		-32767
-#define JSDefaultMax		32767
-#define JSDefaultCenter		0
-#define JSDefaultNullZone	1024
-#define JSDefaultTolorance	10
+#define JSDefaultMin			-32767
+#define JSDefaultMax			32767
+#define JSDefaultCenter			0
+#define JSDefaultNullZone		1024
+#define JSDefaultTolorance		10
 
 
 /*
  *	Joystick Device Flags:
  */
-#define JSFlagIsInit		(1 << 1)
-#define JSFlagNonBlocking	(1 << 2)	/* Open in non-blocking mode */
-#define JSFlagForceFeedback	(1 << 3)	/* Open in read/write mode */
+#define JSFlagIsInit			(1 << 1)
+#define JSFlagNonBlocking		(1 << 2)	/* Open in non-blocking mode */
+#define JSFlagForceFeedback		(1 << 3)	/* Open in read/write mode */
 
 /*
  *	Axis Flags:
  */
-#define JSAxisFlagFlipped	(1 << 1)	/* Flip values */
-#define JSAxisFlagIsHat		(1 << 2)	/* Is a hat */
-#define JSAxisFlagTolorance	(1 << 3)	/* Use error connection */
+#define JSAxisFlagFlipped		(1 << 1)	/* Flip values */
+#define JSAxisFlagIsHat			(1 << 2)	/* Is a hat */
+#define JSAxisFlagTolorance		(1 << 3)	/* Use error connection */
 
 
 /*
  *	Error Codes:
  */
-#define JSSuccess		0
-#define JSError			1
-#define JSBadValue		2
-#define JSNoAccess		3
-#define JSNoBuffers		4
+#define JSSuccess			0
+#define JSError				1
+#define JSBadValue			2
+#define JSNoAccess			3
+#define JSNoBuffers			4
 
 
 /*
  *	Event Codes:
  */
-#define JSNoEvent		0
-#define JSGotEvent		1
+#define JSNoEvent			0
+#define JSGotEvent			1
 
 /*
  *	Button States:
  */
-#define JSButtonStateOff	0
-#define JSButtonStateOn		1
+#define JSButtonStateOff		0
+#define JSButtonStateOn			1
 
 /*
  *	Button Change Codes:
@@ -114,30 +114,30 @@ typedef struct {
 	/* Public */
 
 	/* Axis ranges and bounds (all raw units) */
-	int	cur, prev;	/* Current and previous position */
-	int	min, cen, max;	/* Bounds */
-	int	nz;		/* Null zone, in raw units from cen */
-	int	tolorance;	/* Precision snap in raw units (used only
-				 * if JSAxisFlagTolorance is set) */
+	int		cur, prev;	/* Current and previous position */
+	int		min, cen, max;	/* Bounds */
+	int		nz;		/* Null zone, in raw units from cen */
+	int		tolorance;	/* Precision snap in raw units (used only
+					 * if JSAxisFlagTolorance is set) */
 
 	/* Flags, any of JSAxisFlag* */
 	unsigned int	flags;
 
 	/* Time stamp of current (newest) event and last event (in ms) */
-	time_t	time,
-		last_time;
+	time_t		time,
+			last_time;
 
 	/* Correction level information (new since 1.5.0) */
-	int	correction_level;	/* 0 to 2 supported, higher values
-					 * are allowed */
+	int		correction_level;	/* 0 to 2 supported, higher
+						 * values are allowed */
 
-	int	dz_min,		/* Dead zone bounds in raw units */
-		dz_max;
+	int		dz_min,		/* Dead zone bounds in raw units */
+			dz_max;
 
-	double	corr_coeff_min1,	/* 1st degree correctional coeff */
-		corr_coeff_max1;
-	double	corr_coeff_min2,	/* 2nd degree correctional coeff */
-		corr_coeff_max2;
+	double		corr_coeff_min1,	/* 1st degree correctional coeff */
+			corr_coeff_max1;
+	double		corr_coeff_min2,	/* 2nd degree correctional coeff */
+			corr_coeff_max2;
 
 } js_axis_struct;
 #define JS_AXIS(p)		((js_axis_struct *)(p))
@@ -148,17 +148,17 @@ typedef struct {
 typedef struct {
 
 	/* Current and previous button states, one of JSButtonState* */
-	int	state,
-		prev_state;
+	int		state,
+			prev_state;
 
 	/* Changed state from previous call to JSUpdate(), one of
 	 * JSButtonChangedState*
 	 */
-	int	changed_state;
+	int		changed_state;
 
 	/* Time stamp of current (newest) event and last event (in ms) */
-	time_t	time,
-		last_time;
+	time_t		time,
+			last_time;
 
 } js_button_struct;
 #define JS_BUTTON(p)		((js_button_struct *)(p))
@@ -169,29 +169,29 @@ typedef struct {
 typedef struct {
 
 	/* Public (Read-Only) */
-	char	*name;			/* Descriptive name */
+	char		*name;		/* Descriptive name */
 
 	js_axis_struct **axis;		/* Axises */
-	int	total_axises;
+	int		total_axises;
 
 	js_button_struct **button;	/* Buttons */
-	int	total_buttons;
+	int		total_buttons;
 
-	char	*device_name;		/* Device name */
-	char	*calibration_file;	/* Associated calibration file */
+	char		*device_name;	/* Device name */
+	char		*calibration_file;	/* Associated calibration file */
 
 	unsigned int	events_received,	/* Event counters */
 			events_sent;
 
 	/* Private */
-	int	fd;			/* Descriptor to joystick (can be
-					 * -1 for none) */
+	int		fd;		/* Descriptor to joystick
+					 * (can be -1 for none) */
 	unsigned int	flags;		/* Any of JSFlag* */
 	unsigned int	driver_version;	/* Raw joystick driver version code */
-	time_t	last_calibrated;	/* Last time of calibration in systime
+	time_t		last_calibrated;/* Last time of calibration in systime
 					 * seconds, can be 0 for never
 					 * calibrated */
-	void	*force_feedback;	/* Reserved, always NULL */
+	void		*force_feedback;/* Reserved, always NULL for now */
 
 } js_data_struct;
 #define JS_DARA(p)		((js_data_struct *)(p))
@@ -201,23 +201,21 @@ typedef struct {
  */
 typedef struct {
 
-	char	*name;			/* Descriptive name */
-	char	*device_name;		/* Device name */
+	char		*name;		/* Descriptive name */
+	char		*device_name;	/* Device name */
 
 	/* Specifies that this joystick device is configured and
 	 * calibrated properly if true, otherwise opening this
-	 * joystick may produce unreliable values
-	 */
-	int	is_configured;
+	 * joystick may produce unreliable values */
+	int		is_configured;
 
 	/* If true then suggests device may already be opened */
-	int	is_in_use;
+	int		is_in_use;
 
 	/* Device may not disconnected at the moment, turned off, or
 	 * driver not loaded for it but it may be configured
-	 * (see is_configured for that information)
-	 */
-	int	not_accessable;
+	 * (see is_configured for that information) */
+	int		not_accessable;
 
 } js_attribute_struct;
 #define JS_ATTRIBUTE(p)		((js_attribute_struct *)(p))
