@@ -1176,10 +1176,17 @@ static void PUListBoxDraw(pulistbox_struct *box)
 
 	/* Draw focus if widget is focused */
 	if(GTK_WIDGET_HAS_FOCUS(w) && GTK_WIDGET_SENSITIVE(w))
+#if defined(WIN32)
+	    gdk_draw_rectangle(
+		drawable, style->fg_gc[state], FALSE,
+		0, 0, width - 1, height - 1
+	    );
+#else
 	    gtk_draw_focus(
 		style, drawable,
 		0, 0, width - 1, height - 1
 	    );
+#endif
 
 	/* Send drawable to window if drawable is not the window */
 	if(drawable != window)                                     
@@ -1763,7 +1770,7 @@ const gchar *PUListMapQuery(
 	{
 	    GdkPixmap *pixmap = GDK_PIXMAP_NEW(width, height);
 
-	    GDK_PIXMAP_UNREF(list->shadow_pm)
+	    GDK_PIXMAP_UNREF(list->shadow_pm);
 	    list->shadow_pm = pixmap;
 
 	    if(pixmap != NULL)   
@@ -1835,7 +1842,7 @@ const gchar *PUListMapQuery(
 	/* Unmap */
 	gtk_widget_hide(toplevel);
 	gtk_widget_hide(shadow);
-	GDK_PIXMAP_UNREF(list->shadow_pm)
+	GDK_PIXMAP_UNREF(list->shadow_pm);
 	list->shadow_pm = NULL;
 
 #if 0
@@ -1996,7 +2003,9 @@ pulist_struct *PUListNew(void)
 	    /* No functions */
 	    gdk_window_set_functions(window, 0);
 
+#if !defined(WIN32)
 	    gdk_window_set_override_redirect(window, TRUE);
+#endif
 	}
 
 
@@ -2019,13 +2028,13 @@ void PUListDelete(pulist_struct *list)
 	}
 
 	/* Begin destroying widgets */
-	GTK_WIDGET_DESTROY(list->shadow)
-	GTK_WIDGET_DESTROY(list->clist)
-	GTK_WIDGET_DESTROY(list->scrolled_window)
-	GTK_WIDGET_DESTROY(list->main_vbox)
-	GTK_WIDGET_DESTROY(list->toplevel)
+	GTK_WIDGET_DESTROY(list->shadow);
+	GTK_WIDGET_DESTROY(list->clist);
+	GTK_WIDGET_DESTROY(list->scrolled_window);
+	GTK_WIDGET_DESTROY(list->main_vbox);
+	GTK_WIDGET_DESTROY(list->toplevel);
 
-	GDK_PIXMAP_UNREF(list->shadow_pm)
+	GDK_PIXMAP_UNREF(list->shadow_pm);
 
 	g_free(list->last_value);
 
